@@ -22,7 +22,6 @@
 
 #include <glib/gi18n.h>
 #include <string.h>
-#include <eel/eel-alert-dialog.h>
 #include <libgnomeui/gnome-icon-lookup.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
@@ -82,7 +81,6 @@ typedef struct
 
 	GtkBin *header_bin;
 
-	gboolean renaming;
 	gboolean image_is_broken;
 	gchar * force_icon_name;  //show an icon instead of a thumbnail
 
@@ -342,8 +340,6 @@ document_tile_private_setup (DocumentTile *this)
 	else
 		priv->default_app = NULL;
 
-	priv->renaming = FALSE;
-
 	gnome_vfs_file_info_unref (info);
 
 	priv->delete_enabled =
@@ -376,7 +372,6 @@ document_tile_init (DocumentTile *tile)
 
 	priv->header_bin       = NULL;
 
-	priv->renaming         = FALSE;
 	priv->image_is_broken  = TRUE;
 	priv->force_icon_name  = NULL;
 
@@ -428,9 +423,6 @@ load_image (DocumentTile *tile)
 {
 	DocumentTilePrivate *priv = DOCUMENT_TILE_GET_PRIVATE (tile);
 
-	GdkPixbuf *thumb;
-	gchar *thumb_path;
-
 	gchar *icon_id = NULL;
 	gboolean free_icon_id = TRUE;
 	GnomeThumbnailFactory *thumbnail_factory;
@@ -449,32 +441,7 @@ load_image (DocumentTile *tile)
 
 	thumbnail_factory = libslab_thumbnail_factory_get ();
 
-	thumb_path = gnome_thumbnail_factory_lookup (thumbnail_factory, TILE (tile)->uri, priv->modified);
-
-	if (!thumb_path) {
-		if (
-			gnome_thumbnail_factory_can_thumbnail (
-				thumbnail_factory, TILE (tile)->uri, priv->mime_type, priv->modified)
-		) {
-			thumb = gnome_thumbnail_factory_generate_thumbnail (
-				thumbnail_factory, TILE (tile)->uri, priv->mime_type);
-
-			if (thumb) {
-				gnome_thumbnail_factory_save_thumbnail (
-					thumbnail_factory, thumb, TILE (tile)->uri, priv->modified);
-
-				icon_id = gnome_thumbnail_factory_lookup (
-					thumbnail_factory, TILE (tile)->uri, priv->modified);
-
-				g_object_unref (thumb);
-			}
-			else
-				gnome_thumbnail_factory_create_failed_thumbnail (
-					thumbnail_factory, TILE (tile)->uri, priv->modified);
-		}
-	}
-	else
-		icon_id = thumb_path;
+	icon_id = gnome_thumbnail_factory_lookup (thumbnail_factory, TILE (tile)->uri, priv->modified);
 
 	if (! icon_id)
 		icon_id = gnome_icon_lookup (
@@ -1030,7 +997,6 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
 	DocumentTilePrivate *priv = DOCUMENT_TILE_GET_PRIVATE (tile);
 
-	gchar     *prompt;
 	GtkDialog *confirm_dialog;
 	gint       result;
 
@@ -1041,12 +1007,9 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 
 
 	if (GPOINTER_TO_INT (libslab_get_gconf_value (GCONF_CONFIRM_DELETE_KEY))) {
-		prompt = g_strdup_printf (
-			_("Are you sure you want to permanently delete \"%s\"?"), priv->basename);
-
-		confirm_dialog = GTK_DIALOG (eel_alert_dialog_new (
-			NULL, 0, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
-			prompt, _("If you delete an item, it is permanently lost.")));
+		confirm_dialog = GTK_DIALOG(gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING, 
+				GTK_BUTTONS_NONE, _("Are you sure you want to permanently delete \"%s\"?"), priv->basename));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG(confirm_dialog), _("If you delete an item, it is permanently lost."));
 							
 		gtk_dialog_add_button (confirm_dialog, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		gtk_dialog_add_button (confirm_dialog, GTK_STOCK_DELETE, GTK_RESPONSE_YES);
@@ -1055,7 +1018,6 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 		result = gtk_dialog_run (confirm_dialog);
 
 		gtk_widget_destroy (GTK_WIDGET (confirm_dialog));
-		g_free (prompt);
 
 		if (result != GTK_RESPONSE_YES)
 			return;
